%global _hardened_build   1

%global trackername tracker3

%global pkgver $(rpm -qls %{trackername}-devel.%{_target_cpu} | grep sparql | grep pc | cut -d"-" -f3 | cut -d"." -f1-2|sort -u)
%global with_tracker      1
%global xslver $(rpm -q --queryformat "%%{VERSION}" docbook-style-xsl)
%global with_acls         1
%global with_bdb          1
%global with_cracklib     1
%global with_docbook      1
%global with_dbus         1
%global with_dtrace       1
%global with_ldap         1
%global with_libevent     1
%global with_mysql        1
%global with_procpsng     1
%global with_quota        1
%global without_openafs   1

%global without_tcp_wrappers 1

%global mariadevel mariadb-connector-c-devel


%global python_bin %{python3}

Name:              netatalk
Version:           3.1.18
Release:           2%{?dist}
Summary:           Open Source Apple Filing Protocol(AFP) File Server
License:           GPL+ and GPLv2 and GPLv2+ and LGPLv2+ and BSD and FSFUL and MIT
URL:               http://netatalk.sourceforge.net
Source0:           https://download.sourceforge.net/netatalk/netatalk-%{version}.tar.xz
Source1:           netatalk.pam-system-auth
Source2:           netatalk.conf


Patch0:            netatalk-3.0.1-basedir.patch
Patch1:            netatalk-systemd-execstartpre.patch

BuildRequires:     make
BuildRequires:     rpm
BuildRequires:     grep
BuildRequires:     perl-interpreter
BuildRequires:     perl-generators
BuildRequires:     sed
BuildRequires:     coreutils
BuildRequires:     findutils
BuildRequires:     gcc
BuildRequires:     avahi-devel
BuildRequires:     bison
BuildRequires:     flex
BuildRequires:     libattr-devel
BuildRequires:     libgcrypt-devel
BuildRequires:     krb5-devel
BuildRequires:     openssl-devel
BuildRequires:     pam-devel
BuildRequires:     systemd
BuildRequires:     libtdb-devel

%{?with_cracklib:BuildRequires:     cracklib-devel}
%{?with_dbus:BuildRequires:     dbus-devel}
%{?with_dbus:BuildRequires:     dbus-glib-devel}
%{?with_docbook:BuildRequires:     docbook-style-xsl}
%{?with_acls:BuildRequires:     libacl-devel}
%{?with_bdb:BuildRequires:     libdb-devel}
%{!?with_bdb:BuildRequires:     db4-devel}
%{?with_libevent:BuildRequires:     libevent-devel}
%{?with_docbook:BuildRequires:     libxslt}
%{?with_mysql:BuildRequires:     %{mariadevel}}
%{?with_ldap:BuildRequires:     openldap-devel}
%{?with_procpsng:BuildRequires:     procps-ng}
%{!?with_procng:BuildRequires:     procps}
%{?with_quota:BuildRequires:     quota-devel}
%{?with_dtrace:BuildRequires:     systemtap-sdt-devel}
%{?with_tracker:BuildRequires:     %{trackername}}
%{?with_tracker:BuildRequires:     %{trackername}-devel}
%{!?without_openafs:BuildRequires:     openafs-devel}
%{!?without_tcp_wrappers:BuildRequires:     tcp_wrappers-devel}

Requires:     python3-dbus
%{?with_tracker:Requires:          dconf}
%{?ldconfig:Requires(post): %{ldconfig}}
%{?ldconfig:Requires(postun): %{ldconfig}}
%{?systemd_requires}

Conflicts: jday

%description
Netatalk is a freely-available Open Source AFP file server. A *NIX/*BSD
system running Netatalk is capable of serving many Macintosh clients
simultaneously as an AppleShare file server (AFP).

%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}

%description    devel
This package contains libraries and header files for
developing applications that use %{name}.

%prep
%autosetup -p 1

find include \( -name '*.h' -a -executable \) -exec chmod -x {} \;

sed -i 's\-systemctl daemon-reload\\g' distrib/initscripts/Makefile.in

%build
%configure \
    --localstatedir=%{_localstatedir}/lib       \
    --with-kerberos                             \
    --with-libgcrypt                            \
    --with-pam                                  \
    --with-pkgconfdir=%{_sysconfdir}/netatalk   \
    --with-shadow                               \
    --with-tbd=no                               \
    --with-uams-path=%{_libdir}/netatalk        \
    --enable-pgp-uam                            \
    --enable-shared                             \
    --enable-krbV-uam                           \
    --enable-overwrite                          \
    --with-init-style=redhat-systemd            \
    --without-tdb                               \
    --with-bdb                                  \
    --with-lockfile=%{_rundir}/lock/netatalk/netatalk \
    --disable-silent-rules                      \
    --disable-static                            \
    %{?with_acls:--with-acl}                    \
    %{?with_cracklib:--with-cracklib}           \
    %{?with_docbook:--with-docbook=%{_datadir}/sgml/docbook/xsl-stylesheets-%{xslver}} \
    %{?with_tracker:--with-spotlight}           \
    %{?with_tracker:--with-tracker-pkgconfig-version=%{pkgver}} \
    %{?with_tracker:--with-dbus-daemon=%{_bindir}/dbus-daemon} \
    %{?with_libevent:--without-libevent}        \
    %{?with_libevent:--with-libevent-header=%{_includedir}} \
    %{?with_libevent:--with-libevent-lib=%{_libdir}} \
    %{?with_c99:CFLAGS="$CFLAGS -std=gnu99"}

%make_build
%make_build -C doc/manual html-local

%install
%make_install
install -pm644 %{SOURCE1} %{buildroot}%{_sysconfdir}/pam.d/netatalk

install -Dpm644 %{SOURCE2} %{buildroot}%{_tmpfilesdir}/netatalk.conf

find %{buildroot} -name '*.la' -delete -print

sed -i 's\^#!/usr/bin/env python$\#!%{python_bin}\' %{buildroot}/usr/bin/afpstats

%check
sh test/afpd/test.sh

%post
%systemd_post %{name}.service
%{?ldconfig}

%preun
%systemd_preun %{name}.service

%postun
%systemd_postun_with_restart %{name}.service
%{?ldconfig}

%files
%license COPYING COPYRIGHT
%doc AUTHORS CONTRIBUTORS NEWS doc/manual/*.html
%dir %{_sysconfdir}/netatalk
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/netatalk-dbus.conf
%config(noreplace) %{_sysconfdir}/netatalk/afp.conf
%config(noreplace) %{_sysconfdir}/netatalk/dbus-session.conf
%config(noreplace) %{_sysconfdir}/netatalk/extmap.conf
%config(noreplace) %{_sysconfdir}/pam.d/netatalk
%{_bindir}/*
%exclude %{_bindir}/netatalk-config
%{_libdir}/netatalk/
%{_libdir}/libatalk.so.*
%{_mandir}/man*/*
%exclude %{_mandir}/man*/netatalk-config*
%{_sbindir}/*
%{_unitdir}/netatalk.service
%{_tmpfilesdir}/netatalk.conf
%{_localstatedir}/lib/netatalk

%files devel
%{_bindir}/netatalk-config
%{_datadir}/aclocal/netatalk.m4
%{_includedir}/atalk/
%{_libdir}/libatalk.so
%{_mandir}/man*/netatalk-config.1*

%changelog
* Tue Sep 3 2024 Ze Zhang <bbrucezhang@tencent.com> - 3.1.18-2
- [Type] other
- [DESC] Remove not used macors

* Mon Jul 01 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.1.18-1
- initial build
